@@ -6,10 +6,12 @@ class File(object):
     def __init__(
         self,
         workspaceId,
-        request
+        request,
+        replaceLocalhostString
     ):
         self.workspaceId = workspaceId
         self.request = request
+        self.replaceLocalhostString = replaceLocalhostString
     def getPayload(self):
         return {
             'operationName': 'files',
@@ -37,14 +39,21 @@ class File(object):
     def list_absolute_path(self):
         data = self.fetch()
         return list(map(lambda x: x['absolutePath'], data))
+    def _replace_localhost(self, url):
+        if (self.replaceLocalhostString != None):
+            return url.replace('localhost', self.replaceLocalhostString)
+        else:
+            return url;
     def _get_download_signed_url(self, absolutePath):
         data = self.request.get(f'api/getSignedUrl?workspaceId={self.workspaceId}&objectName={absolutePath}')
         return data
     def _get(self, absolutePath):
         data = self._get_download_signed_url(absolutePath)
+        # quick fix: in notebook we can't get minio data from localhost
+        url = self._replace_localhost(data['signedUrl'])
         http_response = {}
         try:
-            http_response = requests.get(data['signedUrl'])
+            http_response = requests.get(url)
             http_response.raise_for_status()
         except Exception as err:
             content = http_response.get('content')
