@@ -10,7 +10,8 @@ class Workspace(object):
         self,
         endpoint,
         headers,
-        workspaceId
+        workspaceId,
+        replaceLocalhostString
     ):
         self.endpoint = endpoint
         self.headers = headers
@@ -30,5 +31,6 @@ class Workspace(object):
         )
         self.file = File(
             request=request,
-            workspaceId=workspaceId
+            workspaceId=workspaceId,
+            replaceLocalhostString=replaceLocalhostString
         )
\ No newline at end of file
